@@ -1,6 +1,6 @@
 #
 # Scan.pm
-# Last Modification: Tue Mar  2 19:03:13 WET 2004
+# Last Modification: Wed Mar  3 13:20:03 WET 2004
 #
 # Copyright (c) 2004 Henrique Dias <hdias@aesbuc.pt>. All rights reserved.
 # This module is free software; you can redistribute it and/or modify
@@ -19,7 +19,7 @@ use SelfLoader;
 use vars qw($VERSION @ISA @EXPORT $ERROR $SKIPPED $SUSPICIOUS $CALLBACK);
 
 @ISA = qw(Exporter);
-$VERSION = '0.89';
+$VERSION = '0.90';
 
 ($ERROR, $SKIPPED, $SUSPICIOUS, $CALLBACK) = ("", 0, 0, "");
 
@@ -137,7 +137,7 @@ sub callback { $CALLBACK; }
 1;
 
 __DATA__
-# generated in: 2004/03/02 19:33:37
+# generated in: 2004/03/03 13:36:19
 
 sub get_app_sign {
 	$_ = pop;
@@ -145,11 +145,12 @@ sub get_app_sign {
 	/^\x49\x54\x53\x46/o and return($_[0] = 2);
 	/^\xd0\xcf\x11\xe0\xa1\xb1\x1a\xe1/o and return($_[0] = 3);
 	/^\x4d\x5a/o and $_[0] = 4;
-	/^\x4d\x5a\x00\x00\x02/o and return($_[1] = 1);
-	/^\x4d\x5a\x42\x00\x02/o and return($_[1] = 2);
-	/^\x4d\x5a\x50\x00\x02/o and return($_[1] = 3);
-	/^\x4d\x5a\x90\x00\x03/o and return($_[1] = 4);
-	/^\x4d\x5a\x93\x00\x01/o and return($_[1] = 5);
+	/^\x4d\x5a\x00\x00\x01/o and return($_[1] = 1);
+	/^\x4d\x5a\x00\x00\x02/o and return($_[1] = 2);
+	/^\x4d\x5a\x42\x00\x02/o and return($_[1] = 3);
+	/^\x4d\x5a\x50\x00\x02/o and return($_[1] = 4);
+	/^\x4d\x5a\x90\x00\x03/o and return($_[1] = 5);
+	/^\x4d\x5a\x93\x00\x01/o and return($_[1] = 6);
 	/^\xe9/o and return($_[0] = 5);
 	/^\x4d\x53\x46\x54/o and return($_[0] = 6);
 	/^\x47\x45\x54/o and return($_[0] = 7);
@@ -298,13 +299,17 @@ sub scan_binary {
 			}
 		} elsif($type == 4) {
 			if($subtype == 1) {
+				if($total==7168) {
+					/\x31\x35\x31.{0,4}\x2e\x32\x30\x30\x2e\x33\x39/s and $virus = "W32/Bagle.j\@MM", last LINE;
+				}
+			} elsif($subtype == 2) {
 				if($total==1024) {
 					/\x69\x77\x6f\x72\x6d\x2e\x61\x78\x6c\x38\x7a\x65/s and $virus = "W32/Aliz\@MM", last LINE;
 				}
-			} elsif($subtype == 2) {
+			} elsif($subtype == 3) {
 				/\x54\x68\x69\x73\x20\x69\x73\x20\x61\x20\x49\x2d\x57\x6f\x72\x6d\x20\x63\x6f\x64\x65\x64\x20\x62\x79\x20\x42\x75\x6d\x62\x6c\x65\x62\x65\x65\x5c\d+.\x21\x0a\x0a\x47\x72\x65\x74\x69\x6e\x67\x7a\x20\x74\x6f\x20\x61\x6c\x6c\x20\d+.\x20\x6d\x65\x6d\x62\x65\x72\x73\x20\x3b\x29/s and $virus = "W32/Gift.b\@MM", last LINE;
 				/\x54\x68\x69\x73\x20\x69\x73\x20\x50\x6c\x61\x67\x65\x20\d{4}\x20\x63\x6f\x64\x65\x64\x20\x62\x79\x20\x42\x75\x6d\x62\x6c\x65\x62\x65\x65\x2f\d+.\x2e\x00\x50\x6c\x61\x67\x65\x20\d{4}\x20\x41\x63\x74\x69\x76\x61\x74\x69\x6f\x6e/s and $virus = "W32/Plage.gen\@M", last LINE;
-			} elsif($subtype == 3) {
+			} elsif($subtype == 4) {
 				if($total==335872) {
 					/\x28\x63\x29\x20\x62\x79\x20\x45\x6e\x65\x72\x67\x79\x20\x47\x65\x72\x6d\x61\x6e\x79\x20\x53\x53\x54\x40\x48\x61\x62\x6c\x61\x73\x2e\x63\x6f\x6d/s and $virus = "W32/EnerKaz.worm.a", last LINE;
 				}
@@ -373,7 +378,7 @@ sub scan_binary {
 				if($total>=12288 && $total<=28672) {
 					/\x4d\x41.?\x49\x4c\x20\x46\x52.?\x4f.\x3a.\x3c.{17,26}\x52\x43\x50.?\x54\x20.\x4f.{3,4}\x44\x41.{3,6}\x51\x55\x49.{4,9}\x59/s and $virus = "W32/Dumaru\@MM", last LINE;
 				}
-			} elsif($subtype == 4) {
+			} elsif($subtype == 5) {
 				if($total>=19456 && $total<=20480) {
 					/\x3a\x2d\x29\x00\x21\x07\x21\x04[^\x5a]*\x5a\x4f\x4e\x45\x41\x4c\x41\x52\x4d.....\x41\x56\x50..\x4c*\x4f\x43\x4b\x44\x4f\x57\x4e\x32\x30/s and $virus = "W32/Yaha.gen\@MM", last LINE;
 				}
@@ -502,7 +507,7 @@ sub scan_binary {
 					/\xb8\xc7\x64\x83\x71\xfe\xd2\x5c\x06\x38\x4a\xfc\x14\xa3\x98\x53\xd9\x1e\xf9\x69\x7f\x57\x52\x79\x65\x58\x40\x99\x7b\x36\xd6\x58\x06\x3e\xd3\xec\x24\xb4\xb9\x4b\x35\x19\x9a\x05\x3a\x1a\x6f/s and $virus = "W32/Sobig.e\@MM", last LINE;
 					/\x53\x7f\xf3\xff\xff\x75\x6e\x4d\x6f\x6e\x54\x75\x65\x57\x65\x64\x54\x68\x75\x46\x72\x69\x53\x61\x74\x4a\x61\x6e\x46\x65\x62\x4d\xff\xb7\x76\xfb\x61\x72\x41\x70\x72\x05\x79\x4a\x26\x02\x6c\x41\x75\x67\x53\x65\x70\x4f\x63\x74\x5b\x81\xfa\xfd\x4e\x6f\x76\x44\x65\x63\x3f\x54\x5a\x1b\x1c\x74\x7b\xb7\xa9\xff\x69\x6d/s and $virus = "W32/Myparty.b\@MM", last LINE;
 				}
-			} elsif($subtype == 5) {
+			} elsif($subtype == 6) {
 				if($total==162816) {
 					/\xdb\x0f\x84\xb5\x00\x00\x00\x8b\x3b\x3b\xfe\x73\xef\x52\x53\x56\x57\x51\x8b\x55\x18\x83\xe9\x02\x66\x8b\x04\x31\x66\x39\x04\x39\x0f\x85\x8c\x00\x00\x00\x8b\xd9\xc1\xf9\x02\x85\xc9\x74\x11\x8b\x06\x33\x07\x83\xc6\x04\x83\xc7\x04\x85\xc0\x75\x03\x49\x75\xef\x75\x16\x03\xcb\x83\xe1\x03\x85\xc9\x74\x0d\x8a\x06\x8a\x27\x46\x47\x38\xe0\x75\x03\x49\x75\xf3\x75\x58\x59\x5f\x5e\x56\x57\x03\xf9\x03\xf1\x83\xe9\x04\x83\xc1\x04\x8b\xc2\x83\xe8\x04\x78\x28\x3b\xc8/s and $virus = "W32/Fizzer.gen\@MM", last LINE;
 				}
